=== modified file 'database/schema/patch-2208-69-0.sql'
--- database/schema/patch-2208-69-0.sql	2011-05-11 16:29:39 +0000
+++ database/schema/patch-2208-69-0.sql	2011-05-12 10:10:58 +0000
@@ -11,6 +11,8 @@
 UPDATE QuestionMessage SET owner = (
     SELECT owner FROM Message WHERE Message.id=QuestionMessage.message);
 
+ALTER TABLE QuestionMessage ALTER COLUMN owner SET NOT NULL;
+
 -- Triggers to maintain in both directions.
 CREATE TRIGGER questionmessage__owner__mirror
     AFTER UPDATE OR INSERT ON questionmessage

=== modified file 'lib/lp/answers/model/questionmessage.py'
--- lib/lp/answers/model/questionmessage.py	2011-05-11 16:29:39 +0000
+++ lib/lp/answers/model/questionmessage.py	2011-05-12 10:10:58 +0000
@@ -23,6 +23,7 @@
     QuestionStatus,
     )
 from lp.answers.interfaces.questionmessage import IQuestionMessage
+from lp.registry.interfaces.person import validate_public_person
 from lp.services.propertycache import cachedproperty
 
 
@@ -45,6 +46,18 @@
     new_status = EnumCol(
         schema=QuestionStatus, notNull=True, default=QuestionStatus.OPEN)
 
+    owner = ForeignKey(dbName='owner', foreignKey='Person',
+        storm_validator=validate_public_person, notNull=True)
+
+    def __init__(self, **kwargs):
+        if 'owner' not in kwargs:
+            # Although a trigger will set the owner after the SQL
+            # INSERT has been executed, we must specify the parameter
+            # explicitly to fulfill the DB constraint OWNER NOT NULL,
+            # otherweise we'll get an error from the DB server.
+            kwargs['owner'] = kwargs['message'].owner
+        super(QuestionMessage, self).__init__(**kwargs)
+
     def __iter__(self):
         """See IMessage."""
         # Delegates do not proxy __ methods, because of the name mangling.

=== modified file 'lib/lp/answers/model/questionsperson.py'
--- lib/lp/answers/model/questionsperson.py	2011-04-26 16:22:11 +0000
+++ lib/lp/answers/model/questionsperson.py	2011-05-12 10:10:58 +0000
@@ -51,7 +51,7 @@
                   WHERE person = %(personID)s
             UNION SELECT question
                   FROM QuestionMessage JOIN Message ON (message = Message.id)
-                  WHERE owner = %(personID)s
+                  WHERE Message.owner = %(personID)s
             )""" % sqlvalues(personID=self.person.id),
             clauseTables=['Question'], distinct=True))
 

